/* 	XmlHelper.java
 *	Copyright (c) 2004, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 26-nov-2004
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
* [When]		[Who]					[What]
* 09-10-2005	dennis@brains2b.nl      Moved this class from TwelBox to Saxo 0.20
* 14-07-2007    dennis@brains2b.nl      Fixed null value being passed		
*/
package org.brains2b.util;

/** XML Helper class provides some currently used functions for
 * dealing with XML files.
 * <UL>Functions provided are
 * <LI>decode and encode strings</LI>
 * <LI>checking if character is Whitespace</LI>
 * </UL>
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [26-11-2004]
 */
public class XmlHelper {

    /**
     * 
     */
    private XmlHelper() {
        super();
    }

    /**
     * decode xml-encoded String to a normal String
     * <p>Decode will take both the symbol and hex coded
     * variant of the encoded String 
     * @param s String, xml-encoded String
     * @return String, a normal String
     */
    public static final String decode(String s) {
        if (s==null) return null;
		StringBuffer sb=new StringBuffer();
		for (int i=0;i<s.length();i++) {
			char c=s.charAt(i);
			if (c=='&') {
				if (s.substring(i,i+4).equals("&lt;")) {
					sb.append('<');
					i+=3;	
				} else if (s.substring(i,i+4).equals("&gt;")) {
					sb.append('>');
					i+=3;
				} else if (s.substring(i,i+5).equals("&amp;")) {
					sb.append('&');
					i+=4;
				} else if (s.substring(i,i+6).equals("&apos;")) {
					sb.append('\"');
					i+=5;
				} else if (s.substring(i,i+6).equals("&quot;")) {
					sb.append('\'');
					i+=5;
				} else if (s.substring(i,i+3).equals("&#x")) {
					int last=s.indexOf(';',i+3);
					sb.append((char) Integer.parseInt(s.substring(i+3,last),16));
					i=last;
				} 	 					
			} else 
				sb.append(c);
				
		}
		return sb.toString();
	}
    
    /**
     * encode a given String to an xml-encoded String
     * <p>Encode will code only the symboled (apos,quote,lt,gt,amp)
     * characters
     * @param s String, a normal jva String
     * @return String, a xml-encode String
     */
    public static final String encode(String s) {
        //TODO Encode also the hex set of characters
        if (s==null) return null;
		StringBuffer sb=new StringBuffer();
		for (int i=0;i<s.length();i++) {
			char c=s.charAt(i);
			switch (c) {
				case '\"':
					sb.append("&apos;");
					break;
				case '\'':
					sb.append("&quot;");
					break;
				case '<':
					sb.append("&lt;");
					break;
				case '>':
					sb.append("&gt;");
					break;
				case '&':
					sb.append("&amp;");
					break;
				default:
					sb.append(c);
			}
		}
		return sb.toString();
	}
    
    /**
	 * checks if a given character is a whitespace as defined
	 * by XML1.0 specifications
	 * @param c
	 * @return boolean
	 * @since Saxo 0.20
	 */
    public static final boolean isWhitespace(char c) {
		if (c==0x20 || c==0x9 || c==0xA || c==0xD) {
			return true;
		} else {
			return false;
		}
	}
}
