/* 	DummyHandler.java
 *	Copyright (c) 2002, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.saxo;

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.ErrorHandler;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

/** DummyHandler for SAX Parsing
 *  This handler just counts which functions are called, for characters and
 *  ignorable whitespaces the total number of characters is counted. 
 *  A total per function is displayed as soon as endDocument is received.
 *  <p><i>Only used for test purposes</i> called by ContentComparer and ReaderCompareTest<p>
 *
 * @author <A MAILTO="dennis@brains2b.nl">dennis</A>
 * @version 0.10 [14/04/2002]
 */
public class ContentComparer implements ContentHandler, ErrorHandler, Comparable {
    private final static int ELEMENT=0;
    private final static int CONTENT=1; 
    private final static int WHITESPACE=2; 
    private final static int INSTRUCT=3;
    private final static int WARNING=4;
    private final static int ERROR=5;
    private final static int FATAL=6;
    private final static int PREFIX=7;
    
	int[]  m_equals=new int[8];
    long    m_time  =0;
	

	/**
	 * @see ContentHandler#setDocumentLocator(org.xml.sax.Locator)
	 */
	public void setDocumentLocator(Locator arg0) {
		
	}

	/**
	 * @see ContentHandler#startDocument()
	 */
	public void startDocument() throws SAXException {
		for (int i=0;i<m_equals.length;i++) {
            m_equals[i]=0;            
        }
	}

	/**
	 * @see ContentHandler#endDocument()
	 */
	public void endDocument() throws SAXException {
		
	}

	/**
	 * @see ContentHandler#characters(char[], int, int)
	 */
	public void characters(char[] arg0, int arg1, int arg2) throws SAXException {
		if (!(arg2==1 && arg0[arg1]=='\n'))
        m_equals[CONTENT]+=arg2;
	}

	/**
	 * @see ContentHandler#ignorableWhitespace(char[], int, int)
	 */
	public void ignorableWhitespace(char[] arg0, int arg1, int arg2)
		throws SAXException {
		m_equals[WHITESPACE]+=arg2;	
	}

	/**
	 * @see ContentHandler#processingInstruction(java.lang.String, java.lang.String)
	 */
	public void processingInstruction(String arg0, String arg1)
		throws SAXException {
			m_equals[INSTRUCT]++;
	}

	/**
	 * @see ErrorHandler#warning(SAXParseException)
	 */
	public void warning(SAXParseException arg0) throws SAXException {
		m_equals[WARNING]++;
	}

	/**
	 * @see ErrorHandler#error(SAXParseException)
	 */
	public void error(SAXParseException arg0) throws SAXException {
		m_equals[ERROR]++;
	}

	/**
	 * @see ErrorHandler#fatalError(SAXParseException)
	 */
	public void fatalError(SAXParseException arg0) throws SAXException {
		m_equals[FATAL]++;
	}

	/**
	 * @see ContentHandler#endElement(java.lang.String, java.lang.String, java.lang.String)
	 */
    public void endElement(String namespaceURI, String localName, String qName)
            throws SAXException {

    }
    public void endPrefixMapping(String prefix) throws SAXException {

    }
    public void skippedEntity(String name) throws SAXException {

    }

    /**
     * @see ContentHandler#startElement(java.lang.String, java.lang.String, java.lang.String, org.xml.sax.Attributes)
     */
    public void startElement(String namespaceURI, String localName,
            String qName, Attributes atts) throws SAXException {
        m_equals[ELEMENT]++;

    }
    public void startPrefixMapping(String prefix, String uri)
            throws SAXException {
        m_equals[PREFIX]++;   
    }

    public int compareTo(Object o) {
       int result=-1;
       if (o instanceof ContentComparer) {
           result= (int) (m_time-((ContentComparer)o).m_time);
       }
       return result;
    }
    
    public boolean equals(Object o) {
       boolean result=true;
       if (o instanceof ContentComparer) {
           for (int i=0;i<m_equals.length;i++) {
              if (m_equals[i]!=((ContentComparer)o).m_equals[i]) {
                  result=false;
                  break;
              }
           }
       } else {
          result=false;
       }
       return result;
    }

    protected long getTime() {
        return m_time;
    }

    protected void setTime(long time) {
        m_time = time;
    }
}
