/* 	ReaderCompareTest.java
 *	Copyright (c) 2006, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 8-jan-2006
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.saxo;

import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Date;

import org.brains2b.saxo.SAXReader;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

import junit.framework.TestCase;
/** Junit test to compare SAXReader to another Sax compliant reader
 * <p>default the Crimson reader is used, change the REFERENCE constant
 * to compare with another Reader
 * <p>The tests are: it needs to provide the same results as defined
 * in the ContentComparer.equals(Object o) method and be faster then the
 * crimson driver (why else would it exist?)
 * <p>If you find a faster driver, please do not email me about using that one
 * unless you checked the size of the driver package is the same or smaller then 
 * for Saxo and the license allows it to be used without a copy left agreement 
 *  
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [08-01-2006]
 */
public class ReaderCompareTest extends TestCase {
    
    public final static String REFERENCE="org.apache.crimson.parser.XMLReaderImpl";
    
    public static void main(String[] args) {
        junit.swingui.TestRunner.run(ReaderCompareTest.class);
    }

    public ReaderCompareTest(String arg0) {
        super(arg0);
    }

    public void testCompare() {
       
        File [] files=new File("test/xml").listFiles();
        
        for (int i=0;i<files.length;i++) {
            if (!files[i].isDirectory()) { // if it is not a directory asume it is a valid xml file
                try {
                    ContentComparer c1=new ContentComparer();
                    ContentComparer c2=new ContentComparer();
                    XMLReader rRef=XMLReaderFactory.createXMLReader(REFERENCE);
                    parse(rRef,c1,files[i]);
                    XMLReader rSaxo=new SAXReader();
                    parse(rSaxo,c2,files[i]);
                    assertEquals(files[i].getAbsolutePath() + " does not process as equal",c1,c2);
                    assertTrue(files[i].getAbsolutePath() + " is slower in SAXO",c1.compareTo(c2)>0);
                } catch (SAXException saex) {
                    assertTrue(saex.getMessage(),false);
                } catch (IOException iex) {
                    assertTrue(iex.getMessage(),false);
                }
            }
        }
    }
    
    private void parse(XMLReader r,ContentComparer c,File f) throws IOException,SAXException {
        InputSource is=new InputSource(new FileReader(f));
        r.setContentHandler(c);
        Date dt=new Date();
        r.parse(is);
        c.setTime(new Date().getTime()-dt.getTime());
    }
}
