/* 	SAXReaderTest.java
 *	Copyright (c) 2006, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 8-jan-2006
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.saxo;

import org.brains2b.saxo.SAXReader;
import org.xml.sax.SAXException;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

import junit.framework.TestCase;

/** JUnit test for org.brains2b.saxo.SAXReader
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [09-01-2006]
 */
public class SAXReaderTest extends TestCase {

    public static void main(String[] args) {
        junit.swingui.TestRunner.run(SAXReaderTest.class);
    }

    public SAXReaderTest(String arg0) {
        super(arg0);
    }

    public void testDefaultFeatures() {
        SAXReader sax=new SAXReader();
        try {
            assertTrue(sax.getFeature("http://xml.org/sax/features/namespaces"));
            assertTrue(sax.getFeature("http://xml.org/sax/features/namespace-prefixes"));
            assertTrue(!sax.getFeature("http://brains2b.org/saxo/features/track-position"));
        } catch (SAXException saex) {
            assertTrue(saex.getMessage(),false);
        }
    }
    
    public void testSetFeatures() {
        SAXReader sax=new SAXReader();
        final String feature="http://brains2b.org/saxo/features/track-position"; 
        try {
            assertTrue(!sax.getFeature(feature)); //the default
            sax.setFeature(feature,true);
            assertTrue(sax.getFeature(feature)); 
        } catch (SAXException saex) {
            assertTrue(saex.getMessage(),false);
        }
    }
    
    public void testFeatureException() {
        SAXReader sax=new SAXReader();
        try {
            assertTrue(!sax.getFeature("http://brains2b.org/saxo/this-is-not-a-feature"));
        } catch (SAXNotRecognizedException snrex) {
            assertTrue(true);
        } catch (SAXException saex) {
            assertTrue(saex.getMessage(),false);
        }
    }
    
    public void testPropertyException() {
        SAXReader sax=new SAXReader();
        try {
            sax.getProperty("http://brains2b.org/saxo/this-is-not-a-property");
        } catch (SAXNotRecognizedException snrex) {
            assertTrue(true);
        } catch (SAXException saex) {
            assertTrue(saex.getMessage(),false);
        }
        
        try {
            sax.setProperty("http://brains2b.org/saxo/this-is-not-a-property","x");
        } catch (SAXNotRecognizedException snrex) {
            assertTrue(true);
        } catch (SAXException saex) {
            assertTrue(saex.getMessage(),false);
        }
    }
    
    public void testSaxImpl() {
        String old=System.getProperty("org.xml.sax.driver");
        System.setProperty("org.xml.sax.driver","org.brains2b.saxo.SAXReader");
        try {
            XMLReader reader=XMLReaderFactory.createXMLReader();
            assertEquals(reader.getClass(),SAXReader.class);
        } catch (SAXException saex) {
            assertTrue(saex.getMessage(),false);
        } finally {
            if (old!=null) System.setProperty("org.xml.sax.driver",old);
        }
    }
}
